package fi.jyu.mit.fxgui;

import java.util.List;
import java.util.function.Consumer;

import javafx.collections.ObservableList;

/**
 * Simple interface for all different choosers
 * @author terop
 * @version 13.1.2017
 * @param <T> mitä luokkaa tallennetaan
 */
public interface Chooser<T> {
	/**
	 * Adds a single object to the system
	 * @param name name to be displayed in gui
	 * @param object object to be stored
	 */
	void add(String name, T object);
	
	/**
	 * Adds the selection change listener to the component
	 * @param event to listen to
	 */
	void addSelectionListener(Consumer<T> event);
	
	/**
	 * Adds only the object to the system
	 * @param object stored object
	 */
	void add(T object);

	/**
	 * Adds an example string to the gui without stored object
	 * @param name string to be shown on gui
	 */
	void addExample(String name);

	/**
	 * Clears the components of objects
	 */
	void clear();

	/**
	 * Returns the first seleceted object
	 * @return selected object
	 */
	T getSelectedObject();

	/**
	 * Returns the first selected objects gui text
	 * @return text shown on gui
	 */
	String getSelectedText();
	
	/**
	 * Returns the first selected index
	 * @return index
	 */
	int getSelectedIndex();

    /**
     * Sets item in index selected
     * @param index item to be selected
     * @return old selected index
     */
    int setSelectedIndex(int index);
    
    
    /**
     * Sets the selected index to either selected or not selected
     * @param index what index to set
     * @param selected and what to set
     * @return old selected index
     */
    int setSelectedIndex(int index, boolean selected);
	
	/**
     * Sets the rows.
     * 
     * @param jono
     *            A multiline string, each line representing a single row.
     */
    void setRivit(String jono);

    /**
     * Sets the rows.
     * 
     * @param rivit
     *            A string arrays, each line representing a single row.
     */
    void setRivit(String[] rivit);
    
    
    /**
     * Returns the contents as a multiline string.
     * 
     * @return The contents as a multiline string.
     */
    String getRivit();

    
    /**
     * Returns the inner ObservableList. Will break functionality. You have been warned
     * @return the inner observableList
     */
    public ObservableList<StringAndObject<T>> getItems();

    
    /**
     * @return objects stored 
     */
    public List<T> getObjects();
    
}
