package fi.jyu.mit.fxgui;

import java.util.List;

/**
 * Allows selecting multiples of some items from the component
 * @author terop
 * @version 13.1.2017
 * @param <T> Type to store to the chooser component
 */
public interface MultipleChooser<T> extends Chooser<T> {
	/**
	 * Returns all of the selected objects from the components
	 * @return the objects
	 */
	List<T> getSelectedObjects();
	
	/**
	 * Returns all of the selected texts in the components
	 * @return the texts
	 */
	List<String> getSelectedTexts();
	
	/**
	 * Returns all of the selected indices
	 * @return all selected indices
	 */
	List<Integer> getSelectedIndices();
	
	/**
	 * Sets the selected options on for the component
	 * @param selectedOnes the selections in a list
	 */
	void setSelectedIndices(List<Boolean> selectedOnes);
	
	/**
	 * Allows setting indices without a list
	 * @param choices what components to be selected
	 */
	void setSelectedIndices(boolean... choices);
}
